@@ -223,10 +223,10 @@ handle_method_call (GDBusConnection       *connection,
 		g_signal_connect (window, "progress", G_CALLBACK (window_progress_cb), connection);
 		g_signal_connect (window, "ready", G_CALLBACK (window_ready_cb), invocation);
 
-		fr_window_new_batch (FR_WINDOW (window), _("Compress"));
-		fr_window_set_batch__add (FR_WINDOW (window), file, file_list);
-		fr_window_append_batch_action (FR_WINDOW (window), FR_BATCH_ACTION_QUIT, NULL, NULL);
-		fr_window_start_batch (FR_WINDOW (window));
+		fr_window_batch_new (FR_WINDOW (window), _("Compress"));
+		fr_window_batch__add_files (FR_WINDOW (window), file, file_list);
+		fr_window_batch_append_action (FR_WINDOW (window), FR_BATCH_ACTION_QUIT, NULL, NULL);
+		fr_window_batch_start (FR_WINDOW (window));
 
 		g_object_unref (file);
 		_g_object_list_unref (file_list);
@@ -259,10 +259,10 @@ handle_method_call (GDBusConnection       *connection,
 		g_signal_connect (window, "progress", G_CALLBACK (window_progress_cb), connection);
 		g_signal_connect (window, "ready", G_CALLBACK (window_ready_cb), invocation);
 
-		fr_window_new_batch (FR_WINDOW (window), _("Extract archive"));
-		fr_window_set_batch__add (FR_WINDOW (window), NULL, file_list);
-		fr_window_append_batch_action (FR_WINDOW (window), FR_BATCH_ACTION_QUIT, NULL, NULL);
-		fr_window_start_batch (FR_WINDOW (window));
+		fr_window_batch_new (FR_WINDOW (window), _("Compress"));
+		fr_window_batch__add_files (FR_WINDOW (window), NULL, file_list);
+		fr_window_batch_append_action (FR_WINDOW (window), FR_BATCH_ACTION_QUIT, NULL, NULL);
+		fr_window_batch_start (FR_WINDOW (window));
 
 		_g_object_list_unref (file_list);
 		g_object_unref (destination);
@@ -295,10 +295,10 @@ handle_method_call (GDBusConnection       *connection,
 		g_signal_connect (window, "progress", G_CALLBACK (window_progress_cb), connection);
 		g_signal_connect (window, "ready", G_CALLBACK (window_ready_cb), invocation);
 
-		fr_window_new_batch (FR_WINDOW (window), _("Extract archive"));
-		fr_window_set_batch__extract (FR_WINDOW (window), archive, destination);
-		fr_window_append_batch_action (FR_WINDOW (window), FR_BATCH_ACTION_QUIT, NULL, NULL);
-		fr_window_start_batch (FR_WINDOW (window));
+		fr_window_batch_new (FR_WINDOW (window), _("Extract archive"));
+		fr_window_batch__extract (FR_WINDOW (window), archive, destination);
+		fr_window_batch_append_action (FR_WINDOW (window), FR_BATCH_ACTION_QUIT, NULL, NULL);
+		fr_window_batch_start (FR_WINDOW (window));
 
 		g_object_unref (archive);
 		g_object_unref (destination);
@@ -321,10 +321,10 @@ handle_method_call (GDBusConnection       *connection,
 		g_signal_connect (window, "progress", G_CALLBACK (window_progress_cb), connection);
 		g_signal_connect (window, "ready", G_CALLBACK (window_ready_cb), invocation);
 
-		fr_window_new_batch (FR_WINDOW (window), _("Extract archive"));
-		fr_window_set_batch__extract_here (FR_WINDOW (window), archive);
-		fr_window_append_batch_action (FR_WINDOW (window), FR_BATCH_ACTION_QUIT, NULL, NULL);
-		fr_window_start_batch (FR_WINDOW (window));
+		fr_window_batch_new (FR_WINDOW (window), _("Extract archive"));
+		fr_window_batch__extract_here (FR_WINDOW (window), archive);
+		fr_window_batch_append_action (FR_WINDOW (window), FR_BATCH_ACTION_QUIT, NULL, NULL);
+		fr_window_batch_start (FR_WINDOW (window));
 
 		g_object_unref (archive);
 		g_free (uri);
@@ -447,21 +447,21 @@ static void
 fr_application_startup (GApplication *application)
 {
 	GtkSettings	*gtk_settings;
-	gboolean	 show_app_menu;
-	gboolean	 show_menubar;
+	gboolean	 shell_shows_menubar;
 
 	G_APPLICATION_CLASS (fr_application_parent_class)->startup (application);
 
 	fr_application_register_archive_manager_service (FR_APPLICATION (application));
 	initialize_data ();
 
+	/* use the menubar only when the shell shows the menu bar */
+
 	gtk_settings = gtk_settings_get_default ();
 	g_object_get (G_OBJECT (gtk_settings),
-		      "gtk-shell-shows-app-menu", &show_app_menu,
-		      "gtk-shell-shows-menubar", &show_menubar,
+		      "gtk-shell-shows-menubar", &shell_shows_menubar,
 		      NULL);
 
-	if (!show_app_menu || show_menubar)
+	if (shell_shows_menubar)
 		initialize_app_menubar (application);
 	else
 		initialize_app_menu (application);
@@ -564,19 +564,18 @@ fr_application_command_line (GApplication            *application,
 		if (default_directory != NULL)
 			fr_window_set_default_dir (FR_WINDOW (window), default_directory, TRUE);
 
+		fr_window_set_notify (FR_WINDOW (window), arg_notify);
+
 		file_list = NULL;
 		while ((filename = remaining_args[i++]) != NULL)
 			file_list = g_list_prepend (file_list, g_application_command_line_create_file_for_arg (command_line, filename));
 		file_list = g_list_reverse (file_list);
 
-		fr_window_new_batch (FR_WINDOW (window), _("Compress"));
-		fr_window_set_batch__add (FR_WINDOW (window), add_to_archive, file_list);
-
+		fr_window_batch_new (FR_WINDOW (window), _("Compress"));
+		fr_window_batch__add_files (FR_WINDOW (window), add_to_archive, file_list);
 		if (! arg_notify)
-			fr_window_append_batch_action (FR_WINDOW (window), FR_BATCH_ACTION_QUIT, NULL, NULL);
-		else
-			fr_window_set_notify (FR_WINDOW (window), TRUE);
-		fr_window_start_batch (FR_WINDOW (window));
+			fr_window_batch_append_action (FR_WINDOW (window), FR_BATCH_ACTION_QUIT, NULL, NULL);
+		fr_window_batch_start (FR_WINDOW (window));
 
 		_g_object_list_unref (file_list);
 	}
@@ -593,24 +592,23 @@ fr_application_command_line (GApplication            *application,
 		if (default_directory != NULL)
 			fr_window_set_default_dir (FR_WINDOW (window), default_directory, TRUE);
 
-		fr_window_new_batch (FR_WINDOW (window), _("Extract archive"));
+		fr_window_set_notify (FR_WINDOW (window), arg_notify);
+
+		fr_window_batch_new (FR_WINDOW (window), _("Extract archive"));
 		while ((archive = remaining_args[i++]) != NULL) {
 			GFile *file;
 
 			file = g_application_command_line_create_file_for_arg (command_line, archive);
 			if (arg_extract_here == 1)
-				fr_window_set_batch__extract_here (FR_WINDOW (window), file);
+				fr_window_batch__extract_here (FR_WINDOW (window), file);
 			else
-				fr_window_set_batch__extract (FR_WINDOW (window), file, extraction_destination);
+				fr_window_batch__extract (FR_WINDOW (window), file, extraction_destination);
 
 			g_object_unref (file);
 		}
 		if (! arg_notify)
-			fr_window_append_batch_action (FR_WINDOW (window), FR_BATCH_ACTION_QUIT, NULL, NULL);
-		else
-			fr_window_set_notify (FR_WINDOW (window), TRUE);
-
-		fr_window_start_batch (FR_WINDOW (window));
+			fr_window_batch_append_action (FR_WINDOW (window), FR_BATCH_ACTION_QUIT, NULL, NULL);
+		fr_window_batch_start (FR_WINDOW (window));
 	}
 	else { /* Open each archive in a window */
 		const char *filename = NULL;
